@@ -1452,7 +1452,6 @@ fill_sequence (GstVaapiEncoderH265 * encoder, GstVaapiEncSequence * sequence)
 
   seq_param->intra_period = GST_VAAPI_ENCODER_KEYFRAME_PERIOD (encoder);
   seq_param->intra_idr_period = encoder->idr_period;
-  seq_param->ip_period = 1 + encoder->num_bframes;
   seq_param->ip_period = seq_param->intra_period > 1 ?
       (1 + encoder->num_bframes) : 0;
   seq_param->bits_per_second = encoder->bitrate_bits;
@@ -1880,8 +1879,10 @@ ensure_bitrate (GstVaapiEncoderH265 * encoder)
       if (!base_encoder->bitrate) {
         /* Fixme: Provide better estimation */
         /* Using a 1/6 compression ratio */
-        /* 12 bits per pixel fro yuv420 */
-        guint64 factor = encoder->luma_width * encoder->luma_height * 12 / 6;
+        /* 12 bits per pixel for YUV420 */
+        guint64 factor;
+
+        factor = (guint64) encoder->luma_width * encoder->luma_height * 12 / 6;
         base_encoder->bitrate =
             gst_util_uint64_scale (factor, GST_VAAPI_ENCODER_FPS_N (encoder),
             GST_VAAPI_ENCODER_FPS_D (encoder)) / 1000;
