@@ -45,6 +45,39 @@
 #define STRCASEP(p, x)  STRCASE(CONCAT(p, x))
 #define STRCASE(x)      case x: return STRINGIFY(x)
 
+#if VA_CHECK_VERSION (0,40,0)
+static void
+gst_vaapi_log (const char *message)
+{
+  gchar *msg;
+
+  msg = g_strdup (message);
+  if (!msg)
+    return;
+  g_strchomp (msg);
+  GST_INFO ("%s", msg);
+  g_free (msg);
+}
+#endif
+
+gboolean
+vaapi_initialize (VADisplay dpy)
+{
+  gint major_version, minor_version;
+  VAStatus status;
+
+#if VA_CHECK_VERSION (0,40,0)
+  vaSetInfoCallback (gst_vaapi_log);
+#endif
+
+  status = vaInitialize (dpy, &major_version, &minor_version);
+  if (!vaapi_check_status (status, "vaInitialize()"))
+    return FALSE;
+
+  GST_INFO ("VA-API version %d.%d", major_version, minor_version);
+  return TRUE;
+}
+
 /* Check VA status for success or print out an error */
 gboolean
 vaapi_check_status (VAStatus status, const gchar * msg)
@@ -106,9 +139,12 @@ vaapi_create_buffer (VADisplay dpy, VAContextID ctx, int type, guint size,
   *buf_id_ptr = buf_id;
   return TRUE;
 
+  /* ERRORS */
 error:
-  vaapi_destroy_buffer (dpy, &buf_id);
-  return FALSE;
+  {
+    vaapi_destroy_buffer (dpy, &buf_id);
+    return FALSE;
+  }
 }
 
 /* Destroy VA buffer */
@@ -145,6 +181,10 @@ string_of_VAProfile (VAProfile profile)
 #if VA_CHECK_VERSION(0,35,2)
       MAP (H264MultiviewHigh);
       MAP (H264StereoHigh);
+#endif
+#if VA_CHECK_VERSION(0,37,1)
+      MAP (HEVCMain);
+      MAP (HEVCMain10);
 #endif
       MAP (VC1Simple);
       MAP (VC1Main);
@@ -275,6 +315,56 @@ string_of_VARateControl (guint rate_control)
   return "<unknown>";
 }
 
+/**
+ * to_GstVaapiChromaType:
+ * @va_rt_format: the value of VAConfigAttribRTFormat
+ *
+ * Converts the VA_RT_FORMAT_* to #GstVaapiChromaType
+ *
+ * Returns: the #GstVaapiChromaType associated to @va_rt_format or
+ * zero.
+ **/
+guint
+to_GstVaapiChromaType (guint va_rt_format)
+{
+  guint chroma_type;
+
+  switch (va_rt_format) {
+    case VA_RT_FORMAT_YUV420:
+      chroma_type = GST_VAAPI_CHROMA_TYPE_YUV420;
+      break;
+    case VA_RT_FORMAT_YUV422:
+      chroma_type = GST_VAAPI_CHROMA_TYPE_YUV422;
+      break;
+    case VA_RT_FORMAT_YUV444:
+      chroma_type = GST_VAAPI_CHROMA_TYPE_YUV444;
+      break;
+#if VA_CHECK_VERSION(0,34,0)
+    case VA_RT_FORMAT_YUV411:
+      chroma_type = GST_VAAPI_CHROMA_TYPE_YUV411;
+      break;
+    case VA_RT_FORMAT_YUV400:
+      chroma_type = GST_VAAPI_CHROMA_TYPE_YUV400;
+      break;
+    case VA_RT_FORMAT_RGB32:
+      chroma_type = GST_VAAPI_CHROMA_TYPE_RGB32;
+      break;
+    case VA_RT_FORMAT_RGB16:
+      chroma_type = GST_VAAPI_CHROMA_TYPE_RGB16;
+      break;
+#endif
+#if VA_CHECK_VERSION(0,38,1)
+    case VA_RT_FORMAT_YUV420_10BPP:
+      chroma_type = GST_VAAPI_CHROMA_TYPE_YUV420_10BPP;
+      break;
+#endif
+    default:
+      chroma_type = 0;
+      break;
+  }
+  return chroma_type;
+}
+
 /**
  * from_GstVaapiChromaType:
  * @chroma_type: the #GstVaapiChromaType
